@@ -12,7 +12,7 @@ macro_rules! one_unit {
         $abbr1:literal,
         $abbr2:literal) => {
         $crate::paste::item! {
-            pub static [<$prefix:upper $unit_pre:upper $base:upper>]: dims_core::unit_creation::UnitFormat<$system> =
+            pub const [<$prefix:upper $unit_pre:upper $base:upper>]: dims_core::unit_creation::UnitFormat<$system> =
             dims_core::unit_creation::UnitFormat::<$system> {
                 system: dims_core::unit_creation::PhantomData,
                 ratio: repeat_item!($ratio, $repeat),
